;; Generated package description from mode: lisp-data; .el  -*- denote-orgno-byte-compile: t -*-
(define-package "denote-org" "0.1.0" "Denote extensions for Org mode" '((emacs "28.1") (denote "3.1.0")) :commit "7c8d53bf8e4ee073b1654ad0221be01e7801d4c6" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-org")
